.. GottWall Scalable Realtime Statistics Aggregator documentation master file, created by
   sphinx-quickstart on Sun Dec 16 23:53:58 2012.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to GottWall Scalable Realtime Statistics Aggregator's documentation!
============================================================================

Users Guide:

.. toctree::
   :maxdepth: 2

   quickstart
   clients

Developers:

.. toctres::
   :maxdepth: 2

    developers/clients


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

